### R code from vignette source 'nlraa.Rnw'

###################################################
### code chunk number 1: preliminaries
###################################################
options(width=65,digits=5)
library(nlme)
library(ggplot2)
library(nlraa)
library(lattice)


###################################################
### code chunk number 2: strsm
###################################################
data(sm)
str(sm)
sm


###################################################
### code chunk number 3: nlraa.Rnw:85-87
###################################################
sm$eu <- with(sm, factor(Block):factor(Input):factor(Crop))
sm2 <- subset(sm, DOY != 141)


###################################################
### code chunk number 4: nlraa.Rnw:93-94
###################################################
smG <- groupedData(Yield ~ DOY | eu, data = sm2)


###################################################
### code chunk number 5: nlraa.Rnw:101-102
###################################################
fit.lis <- nlsList(Yield ~ SSbgf(DOY, w.max, t.e, t.m), data = smG)


###################################################
### code chunk number 6: nlslisResid
###################################################
print(plot(fit.lis))


###################################################
### code chunk number 7: nlslisIntervals
###################################################
print(plot(intervals(fit.lis)))


###################################################
### code chunk number 8: nlraa.Rnw:136-137
###################################################
fit.me <- nlme(fit.lis, control = list(minScale =1e-50, pnlsTol=0.01))


###################################################
### code chunk number 9: nlmeResid
###################################################
print(plot(fit.me))


###################################################
### code chunk number 10: nlmeAugPred
###################################################
print(plot(augPred(fit.me, level = 0:1)))


###################################################
### code chunk number 11: nlraa.Rnw:173-176
###################################################
fit.lis2 <- nlsList(Yield ~ bgf2(DOY, w.max, w.b = 0, t.e, t.m, t.b = 141),
                    data = smG,
                    start = c(w.max = 30, t.e=280, t.m=240))


###################################################
### code chunk number 12: nlslisResid2
###################################################
print(plot(fit.lis2))


###################################################
### code chunk number 13: nlraa.Rnw:194-197
###################################################
fit.me2 <- nlme(fit.lis2)
fit2.me2 <- update(fit.me2, random = pdDiag(w.max + t.e + t.m ~ 1))
anova(fit.me2, fit2.me2)


###################################################
### code chunk number 14: nlraa.Rnw:204-220
###################################################
fe <- fixef(fit2.me2) ## Some starting values with visual help
fit3.me2 <- update(fit2.me2, fixed = list(w.max + t.e + t.m ~ Crop),
                  start = c(fe[1], -10, 20, fe[2], -40, 0, fe[3], -40, 0))
## We next include the Input
fe2 <- fixef(fit3.me2)
fit4.me2 <- update(fit3.me2, fixed = list(w.max + t.e + t.m
                               ~ Crop + Input),
                  start = c(fe2[1:3], 0, fe2[4:6], 0, fe2[7:9], 0))
## and the interaction
fe3 <- fixef(fit4.me2)
fit5.me2 <- update(fit4.me2,
                   fixed = list(w.max + t.e + t.m
                     ~ Crop + Input + Crop:Input),
                  start = c(fe3[1:4], 0, 0,
                            fe3[5:8], 0, 0,
                            fe3[9:12], 0, 0))


###################################################
### code chunk number 15: nlmeResid2
###################################################
print(plot(fit5.me2))


###################################################
### code chunk number 16: nlraa.Rnw:242-248
###################################################
fit6.me2 <- update(fit5.me2,
                   weights = varPower(form = ~ fitted(.) | Crop))

fit7.me2 <- update(fit6.me2, weights = varPower(form = ~ fitted(.)))

anova(fit6.me2, fit7.me2)


###################################################
### code chunk number 17: nlraa.Rnw:254-255
###################################################
fit6.me2


###################################################
### code chunk number 18: nlraa.Rnw:261-269
###################################################
## Random effects are almost zero
fit8.me2 <- gnls(Yield ~ bgf2(DOY, w.max, t.e, t.m, w.b=0, t.b=141),
                 data = smG,
                 params = list(w.max + t.e + t.m ~ Crop + Input
                                                   + Crop:Input),
                 weights = varPower(form = ~ fitted(.) | Crop),
                 start = fixef(fit7.me2))
anova(fit6.me2, fit8.me2)


###################################################
### code chunk number 19: nlraa.Rnw:274-275
###################################################
anova(fit8.me2)


###################################################
### code chunk number 20: nlraa.Rnw:284-285
###################################################
print(plot(fit8.me2))


###################################################
### code chunk number 21: nlraa.Rnw:290-299
###################################################
smG$prds <- fitted(fit8.me2)

doys <- 168:303
ndat <- expand.grid(DOY=doys, Crop= unique(smG$Crop), Input=c(1,2))
ndat$preds <- predict(fit8.me2, newdata = ndat)

ndat2 <- ndat
ndat2[ndat2$Crop == "M" & ndat2$DOY > 270,"preds"] <- NA
ndat2 <- na.omit(ndat2)


